summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qbrush.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qbrush.h')
-rw-r--r--kjsembed/tools/headers/qbrush.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kjsembed/tools/headers/qbrush.h b/kjsembed/tools/headers/qbrush.h
index 93f17e28..038e7699 100644
--- a/kjsembed/tools/headers/qbrush.h
+++ b/kjsembed/tools/headers/qbrush.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of TTQBrush class
**
** Created : 940112
**
@@ -44,33 +44,33 @@
#endif // QT_H
-class Q_EXPORT TTQBrush: public Qt
+class Q_EXPORT TQBrush: public Qt
{
-friend class TTQPainter;
+friend class TQPainter;
public:
- TTQBrush();
- TTQBrush( BrushStyle );
- TTQBrush( const TTQColor &, BrushStyle=SolidPattern );
- TTQBrush( const TTQColor &, const TTQPixmap & );
- TTQBrush( const TTQBrush & );
- ~TTQBrush();
- TTQBrush &operator=( const TTQBrush & );
+ TQBrush();
+ TQBrush( BrushStyle );
+ TQBrush( const TQColor &, BrushStyle=SolidPattern );
+ TQBrush( const TQColor &, const TQPixmap & );
+ TQBrush( const TQBrush & );
+ ~TQBrush();
+ TQBrush &operator=( const TQBrush & );
BrushStyle style() const { return data->style; }
void setStyle( BrushStyle );
- const TTQColor &color()const { return data->color; }
- void setColor( const TTQColor & );
- TTQPixmap *pixmap() const { return data->pixmap; }
- void setPixmap( const TTQPixmap & );
+ const TQColor &color()const { return data->color; }
+ void setColor( const TQColor & );
+ TQPixmap *pixmap() const { return data->pixmap; }
+ void setPixmap( const TQPixmap & );
- bool operator==( const TTQBrush &p ) const;
- bool operator!=( const TTQBrush &b ) const
+ bool operator==( const TQBrush &p ) const;
+ bool operator!=( const TQBrush &b ) const
{ return !(operator==(b)); }
private:
TQBrush copy() const;
void detach();
- void init( const TTQColor &, BrushStyle );
+ void init( const TQColor &, BrushStyle );
struct TQBrushData : public TQShared { // brush data
BrushStyle style;
TQColor color;
@@ -80,12 +80,12 @@ private:
/*****************************************************************************
- TTQBrush stream functions
+ TQBrush stream functions
*****************************************************************************/
#ifndef QT_NO_DATASTREAM
-Q_EXPORT TTQDataStream &operator<<( TTQDataStream &, const TTQBrush & );
-Q_EXPORT TTQDataStream &operator>>( TTQDataStream &, TTQBrush & );
+Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQBrush & );
+Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQBrush & );
#endif
#endif // TQBRUSH_H
@@ -1,7 +1,7 @@
**
**
-** Definition of TTQBrush class
+** Definition of TQBrush class
**
** Created : 940112